pub struct DecodeSnappy;Trait Implementations
Sourceimpl Clone for DecodeSnappy
impl Clone for DecodeSnappy
Sourcefn clone(&self) -> DecodeSnappy
fn clone(&self) -> DecodeSnappy
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecodeSnappy
impl Debug for DecodeSnappy
Sourceimpl Function for DecodeSnappy
impl Function for DecodeSnappy
Sourcefn identifier(&self) -> &'static str
fn identifier(&self) -> &'static str
The identifier by which the function can be called.
Sourcefn usage(&self) -> &'static str
fn usage(&self) -> &'static str
A more elaborate multi-paragraph description on how to use the function.
Sourcefn internal_failure_reasons(&self) -> &'static [&'static str]
fn internal_failure_reasons(&self) -> &'static [&'static str]
Human-readable internal failure reasons for the function. Read more
Sourcefn return_kind(&self) -> u16
fn return_kind(&self) -> u16
The return type kind(s) this function can return.
Sourcefn examples(&self) -> &'static [Example]
fn examples(&self) -> &'static [Example]
One or more examples demonstrating usage of the function in VRL source
code.
Sourcefn compile(
&self,
_state: &TypeState,
_ctx: &mut FunctionCompileContext,
arguments: ArgumentList,
) -> Compiled
fn compile( &self, _state: &TypeState, _ctx: &mut FunctionCompileContext, arguments: ArgumentList, ) -> Compiled
Sourcefn parameters(&self) -> &'static [Parameter]
fn parameters(&self) -> &'static [Parameter]
An optional list of parameters the function accepts. Read more
Sourcefn summary(&self) -> &'static str
fn summary(&self) -> &'static str
A brief single-line description explaining what this function does.
Sourcefn return_rules(&self) -> &'static [&'static str]
fn return_rules(&self) -> &'static [&'static str]
Human-readable rules describing the return value of the function. Read more
Sourcefn notices(&self) -> &'static [&'static str]
fn notices(&self) -> &'static [&'static str]
Important notices about the function’s behavior or usage. Read more
impl Copy for DecodeSnappy