TypeDef

Struct TypeDef 

pub struct TypeDef;
A debug function to print the type definition of an expression at runtime.

This function is UNDOCUMENTED and UNSTABLE. It is NOT to be advertised to users of Vector, even though it is technically usable by others.